All Classes and Interfaces
Class
Description
A custom action to use in stateless rule actions settings.
A single IP address specification.
A report that captures key activity from the last 30 days of network traffic monitored by your firewall.
The analysis result for Network Firewall's stateless rule group analyzer.
The results of a
COMPLETED analysis report generated with StartAnalysisReport.An AWS Arn.
AssociateAvailabilityZonesRequest MarshallerAssociateFirewallPolicyRequest MarshallerAssociateSubnetsRequest Marshaller
The definition and status of the firewall endpoint for a single subnet.
AttachRuleGroupsToProxyConfigurationRequest Marshaller
Defines the mapping between an Availability Zone and a firewall endpoint for a transit gateway-attached firewall.
High-level information about an Availability Zone where the firewall has an endpoint defined.
The status of the firewall endpoint defined by a
VpcEndpointAssociation.
The capacity usage summary of the resources used by the ReferenceSets in a firewall.
Defines the actions to take on the SSL/TLS connection if the certificate presented by the server in the connection
has a revoked or unknown status.
Summarizes the CIDR blocks used by the IP set references in a firewall.
High-level information about a container association, returned by the ListContainerAssociations operation.
A key-value pair that defines a container attribute filter for a container monitoring configuration.
Defines a container cluster to monitor, along with optional attribute filters that narrow the scope of monitored
containers within the cluster.
CreateContainerAssociationRequest MarshallerCreateFirewallPolicyRequest MarshallerCreateFirewallRequest MarshallerCreateProxyConfigurationRequest MarshallerCreateProxyRequest Marshaller
Individual rules that define match conditions and actions for application-layer traffic.
CreateProxyRuleGroupRequest Marshaller
Evaluation points in the traffic flow where rules are applied.
CreateProxyRulesRequest MarshallerCreateRuleGroupRequest MarshallerCreateTlsInspectionConfigurationRequest MarshallerCreateVpcEndpointAssociationRequest Marshaller
An optional, non-standard action to use for stateless packet handling.
DeleteContainerAssociationRequest MarshallerDeleteFirewallPolicyRequest MarshallerDeleteFirewallRequest MarshallerDeleteProxyConfigurationRequest MarshallerDeleteProxyRequest MarshallerDeleteProxyRuleGroupRequest MarshallerDeleteProxyRulesRequest MarshallerDeleteResourcePolicyRequest MarshallerDeleteRuleGroupRequest MarshallerDeleteTlsInspectionConfigurationRequest MarshallerDeleteVpcEndpointAssociationRequest MarshallerDescribeContainerAssociationRequest MarshallerDescribeFirewallMetadataRequest MarshallerDescribeFirewallPolicyRequest MarshallerDescribeFirewallRequest MarshallerDescribeFlowOperationRequest MarshallerDescribeLoggingConfigurationRequest MarshallerDescribeProxyConfigurationRequest MarshallerDescribeProxyRequest Marshaller
Proxy attached to a NAT gateway.
DescribeProxyRuleGroupRequest MarshallerDescribeProxyRuleRequest MarshallerDescribeResourcePolicyRequest MarshallerDescribeRuleGroupMetadataRequest MarshallerDescribeRuleGroupRequest MarshallerDescribeRuleGroupSummaryRequest MarshallerDescribeTlsInspectionConfigurationRequest MarshallerDescribeVpcEndpointAssociationRequest Marshaller
The value to use in an Amazon CloudWatch custom metric dimension.
DisassociateAvailabilityZonesRequest MarshallerDisassociateSubnetsRequest Marshaller
A complex type that contains optional Amazon Web Services Key Management Service (KMS) encryption settings for your
Network Firewall resources.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
A firewall defines the behavior of a firewall, the main VPC where the firewall is used, the Availability Zones where
the firewall can be used, and one subnet to use for a firewall endpoint within each of the Availability Zones.
High-level information about a firewall, returned by operations like create and describe.
The firewall policy defines the behavior of a firewall using a collection of stateless and stateful rule groups and
other settings.
High-level information about a firewall policy, returned by operations like create and describe.
The high-level properties of a firewall policy.
Detailed information about the current status of a Firewall.
Any number of arrays, where each array is a single flow identified in the scope of the operation.
Defines the scope a flow operation.
Contains information about a flow operation, such as related statuses, unique identifiers, and all filters defined in
the operation.
An array of objects with metadata about the requested
FlowOperation.
Describes the amount of time that can pass without any traffic sent through the firewall before the firewall
determines that the connection is idle and Network Firewall removes the flow entry from its flow table.
Represents the output for the
NetworkFirewallClient.getAnalysisReportResultsPaginator(software.amazon.awssdk.services.networkfirewall.model.GetAnalysisReportResultsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.getAnalysisReportResultsPaginator(software.amazon.awssdk.services.networkfirewall.model.GetAnalysisReportResultsRequest)
operation which is a paginated operation.GetAnalysisReportResultsRequest Marshaller
The basic rule criteria for Network Firewall to use to inspect packet headers in stateful traffic flow inspection.
Attempts made to a access domain.
Identifiers for variables declared within the rule engine, e.g.
Amazon Web Services doesn't currently have enough available capacity to fulfill your request.
Your request is valid, but Network Firewall couldn't perform the operation because of a system problem.
The operation failed because it's not valid.
The operation failed because of a problem with your request.
The policy statement failed validation.
The token you provided is stale or isn't valid for the operation.
A list of IP addresses and address ranges, in CIDR notation.
General information about the IP set.
Configures one or more IP set references for a Suricata-compatible rule group.
Unable to perform the operation because doing so would violate a limit setting.
Represents the output for the
NetworkFirewallClient.listAnalysisReportsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListAnalysisReportsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listAnalysisReportsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListAnalysisReportsRequest)
operation which is a paginated operation.ListAnalysisReportsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listContainerAssociationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListContainerAssociationsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listContainerAssociationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListContainerAssociationsRequest)
operation which is a paginated operation.ListContainerAssociationsRequest Marshaller
Open port for taking HTTP or HTTPS traffic.
This data type is used specifically for the CreateProxy and UpdateProxy APIs.
Represents the output for the
NetworkFirewallClient.listFirewallPoliciesPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFirewallPoliciesRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listFirewallPoliciesPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFirewallPoliciesRequest)
operation which is a paginated operation.ListFirewallPoliciesRequest Marshaller
Represents the output for the
NetworkFirewallClient.listFirewallsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFirewallsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listFirewallsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFirewallsRequest)
operation which is a paginated operation.ListFirewallsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listFlowOperationResultsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFlowOperationResultsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listFlowOperationResultsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFlowOperationResultsRequest)
operation which is a paginated operation.ListFlowOperationResultsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listFlowOperationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFlowOperationsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listFlowOperationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListFlowOperationsRequest)
operation which is a paginated operation.ListFlowOperationsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listProxiesPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxiesRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listProxiesPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxiesRequest)
operation which is a paginated operation.ListProxiesRequest Marshaller
Represents the output for the
NetworkFirewallClient.listProxyConfigurationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxyConfigurationsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listProxyConfigurationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxyConfigurationsRequest)
operation which is a paginated operation.ListProxyConfigurationsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listProxyRuleGroupsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxyRuleGroupsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listProxyRuleGroupsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListProxyRuleGroupsRequest)
operation which is a paginated operation.ListProxyRuleGroupsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listRuleGroupsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListRuleGroupsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listRuleGroupsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListRuleGroupsRequest)
operation which is a paginated operation.ListRuleGroupsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listTagsForResourcePaginator(software.amazon.awssdk.services.networkfirewall.model.ListTagsForResourceRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listTagsForResourcePaginator(software.amazon.awssdk.services.networkfirewall.model.ListTagsForResourceRequest)
operation which is a paginated operation.ListTagsForResourceRequest Marshaller
Represents the output for the
NetworkFirewallClient.listTLSInspectionConfigurationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListTlsInspectionConfigurationsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listTLSInspectionConfigurationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListTlsInspectionConfigurationsRequest)
operation which is a paginated operation.ListTlsInspectionConfigurationsRequest Marshaller
Represents the output for the
NetworkFirewallClient.listVpcEndpointAssociationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListVpcEndpointAssociationsRequest)
operation which is a paginated operation.
Represents the output for the
NetworkFirewallAsyncClient.listVpcEndpointAssociationsPaginator(software.amazon.awssdk.services.networkfirewall.model.ListVpcEndpointAssociationsRequest)
operation which is a paginated operation.ListVpcEndpointAssociationsRequest Marshaller
Defines where Network Firewall sends logs for the firewall for one log type.
Unable to send logs to a configured logging destination.
Defines how Network Firewall performs logging for a Firewall.
Criteria for Network Firewall to use to inspect an individual packet in stateless rule inspection.
Service client for accessing Network Firewall asynchronously.
A builder for creating an instance of
NetworkFirewallAsyncClient.The parameters object used to resolve the auth schemes for the NetworkFirewall service.
A builder for a
NetworkFirewallAuthSchemeParams.An auth scheme provider for NetworkFirewall service.
This includes configuration specific to Network Firewall that is supported by both
NetworkFirewallClientBuilder and NetworkFirewallAsyncClientBuilder.Service client for accessing Network Firewall.
A builder for creating an instance of
NetworkFirewallClient.The parameters object used to resolve an endpoint for the NetworkFirewall service.
An endpoint provider for NetworkFirewall.
Class to expose the service client settings to the user.
A builder for creating a
NetworkFirewallServiceClientConfiguration
Provides configuration status for a single policy or rule group that is used for a firewall endpoint.
Contains variables that you can use to override default Suricata settings in your firewall policy.
A single port range specification.
A set of port ranges for use in the rules in a rule group.
Proxy attached to a NAT gateway.
Evaluation points in the traffic flow where rules are applied.
Proxy rule group contained within a proxy configuration.
A Proxy Configuration defines the monitoring and protection behavior for a Proxy.
High-level information about a proxy configuration, returned by operations like create and describe.
High-level information about a proxy, returned by operations like create and describe.
Individual rules that define match conditions and actions for application-layer traffic.
Match criteria that specify what traffic attributes to examine.
Collections of related proxy filtering rules.
The proxy rule group(s) to attach to the proxy configuration
High-level information about a proxy rule group, returned by operations like create and describe.
Proxy rule group name and new desired position.
Proxy rule group along with its priority.
Proxy rule name and new desired position.
Evaluation points in the traffic flow where rules are applied.
Stateless inspection criteria that publishes the specified metrics to Amazon CloudWatch for the matching packet.
PutResourcePolicyRequest Marshaller
Contains a set of IP set references.
Unable to locate a resource using the parameters that you provided.
Unable to change the resource because your account doesn't own it.
The inspection criteria and action for a single stateless rule.
The object that defines the rules in a rule group.
High-level information about a rule group, returned by ListRuleGroups.
The high-level properties of a rule group.
Additional settings for a stateful rule.
The stateless or stateful rules definitions for use in a single rule group.
Stateful inspection criteria for a domain list rule group.
A complex type containing details about a Suricata rule.
Represents a URL to be used internally for endpoint resolution.
Settings that are available for use in the rules in the RuleGroup where this is defined.
Any Certificate Manager (ACM) Secure Sockets Layer/Transport Layer Security (SSL/TLS) server certificate that's
associated with a ServerCertificateConfiguration.
Configures the Certificate Manager certificates and scope that Network Firewall uses to decrypt and re-encrypt
traffic using a TLSInspectionConfiguration.
Settings that define the Secure Sockets Layer/Transport Layer Security (SSL/TLS) traffic that Network Firewall should
decrypt for inspection by the stateful rule engine.
High-level information about the managed rule group that your own rule group is copied from.
StartAnalysisReportRequest MarshallerStartFlowCaptureRequest MarshallerStartFlowFlushRequest Marshaller
Configuration settings for the handling of the stateful rule groups in a firewall policy.
A single Suricata rules specification, for use in a stateful rule group.
The setting that allows the policy owner to change the behavior of the rule group within a policy.
Identifier for a single stateful rule group, used in a firewall policy to refer to a rule group.
Additional options governing how Network Firewall handles the rule group.
A single stateless rule.
Identifier for a single stateless rule group, used in a firewall policy to refer to the rule group.
Stateless inspection criteria.
The ID for a subnet that's used in an association with a firewall.
A complex type containing summaries of security protections provided by a rule group.
A complex type that specifies which Suricata rule metadata fields to use when displaying threat information.
The status of the firewall endpoint and firewall policy configuration for a single VPC subnet.
A key:value pair associated with an Amazon Web Services resource.
TagResourceRequest Marshaller
TCP flags and masks to inspect packets for, used in stateless rules MatchAttributes settings.
Unable to process the request due to throttling limitations.
Contains metadata about an Certificate Manager certificate.
The object that defines a TLS inspection configuration.
High-level information about a TLS inspection configuration, returned by
ListTLSInspectionConfigurations
.
The high-level properties of a TLS inspection configuration.
TLS decryption on traffic to filter on attributes in the HTTP header.
This data type is used specifically for the CreateProxy and UpdateProxy APIs.
Contains information about the synchronization state of a transit gateway attachment, including its current status
and any error messages.
A unique source IP address that connected to a domain.
The operation you requested isn't supported by Network Firewall.
UntagResourceRequest MarshallerUpdateContainerAssociationRequest MarshallerUpdateFirewallAnalysisSettingsRequest MarshallerUpdateFirewallDeleteProtectionRequest MarshallerUpdateFirewallDescriptionRequest MarshallerUpdateFirewallEncryptionConfigurationRequest MarshallerUpdateFirewallPolicyChangeProtectionRequest MarshallerUpdateFirewallPolicyRequest MarshallerUpdateLoggingConfigurationRequest MarshallerUpdateProxyConfigurationRequest MarshallerUpdateProxyRequest MarshallerUpdateProxyRuleGroupPrioritiesRequest MarshallerUpdateProxyRulePrioritiesRequest MarshallerUpdateProxyRuleRequest MarshallerUpdateRuleGroupRequest MarshallerUpdateSubnetChangeProtectionRequest MarshallerUpdateTlsInspectionConfigurationRequest MarshallerBase class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
A VPC endpoint association defines a single subnet to use for a firewall endpoint for a
Firewall.
High-level information about a VPC endpoint association, returned by
ListVpcEndpointAssociations.
Detailed information about the current status of a VpcEndpointAssociation.